@@ -20,9 +20,10 @@
 #define GLOBAL_INTERFACE_KEY "/desktop/gnome/interface"
 
 static GConfEnumStringPair toolbar_styles[] = {
-        { BONOBO_UI_TOOLBAR_STYLE_PRIORITY_TEXT, "text" },
-        { BONOBO_UI_TOOLBAR_STYLE_ICONS_ONLY, "icons" },
-        { BONOBO_UI_TOOLBAR_STYLE_ICONS_AND_TEXT, "both" }
+        { BONOBO_UI_TOOLBAR_STYLE_TEXT_ONLY,      "text" },
+        { BONOBO_UI_TOOLBAR_STYLE_ICONS_ONLY,     "icons" },
+        { BONOBO_UI_TOOLBAR_STYLE_ICONS_AND_TEXT, "both" },
+        { BONOBO_UI_TOOLBAR_STYLE_PRIORITY_TEXT,  "both_horiz" }
 };
 
 static GConfClient *client;
@@ -124,11 +125,12 @@ bonobo_ui_preferences_shutdown (void)
 	if (client) {
 		g_object_unref (client);
 		client = NULL;
-		ret = gconf_debug_shutdown ();
-		if (ret)
-			g_warning ("GConf's dirty shutdown");
 	}
 
+	ret = gconf_debug_shutdown ();
+	if (ret)
+		g_warning ("GConf's dirty shutdown");
+
 	return ret;
 }
 
@@ -164,13 +166,11 @@ bonobo_ui_preferences_get_toolbar_style (void)
 				       NULL);
 	
 	if (str != NULL) {
-		gconf_string_to_enum(toolbar_styles,
-				     str,
-				     (gint*)&style);
-		g_free(str);
+		gconf_string_to_enum (toolbar_styles,
+				      str, (gint *)&style);
+		g_free (str);
 	}
 
-
 	return style;
 }
 
